#!/bin/bash
#
# build-server.sh
#
# Copyright (C) 2011-2012 Cesnet z.s.p.o
#
# Use of this source is governed by a BSD-style license, see LICENSE file.

VERSION="2.1"

err()
{
  echo "FAILED!"
  cat $err
  rm -rf $err $package $tar $sig
  echo
  echo "Build of $package package FAILED!!!"
  exit 1
}


#-------------------------------------------------------------------------------
#				MAIN
#-------------------------------------------------------------------------------

# edit when you build new package
version="2.1"

package_name="warden-server"
package="${package_name}-${version}"
bin="${package}/${package_name}/bin"
doc="${package}/${package_name}/doc"
etc="${package}/${package_name}/etc"
lib="${package}/${package_name}/lib"
tar="${package}.tar.gz"
sig="${tar}.sig"
err="/tmp/${package}-err"

# make directory structure
echo "Building $package_name package version $version ..."
echo

echo -n "Building 'base' directory ... "
mkdir -p $package 2> $err || err
cp ../src/${package_name}/sh/install.sh $package 2> $err || err
cp ../src/${package_name}/sh/update.sh $package 2> $err || err
cp ../src/${package_name}/sh/uninstall.sh $package 2> $err || err
cp ../src/${package_name}/sh/uninstall.sh $package 2> $err || err
cp ../src/${package_name}/doc/AUTHORS $package 2> $err || err
cp ../src/${package_name}/doc/CHANGELOG $package 2> $err || err
cp ../src/${package_name}/doc/INSTALL $package 2> $err || err
cp ../src/${package_name}/doc/LICENSE $package 2> $err || err
cp ../src/${package_name}/doc/README $package 2> $err || err
cp ../src/${package_name}/doc/UNINSTALL $package 2> $err || err
cp ../src/${package_name}/doc/UPDATE $package 2> $err || err

echo "OK"

echo -n "Building '${bin}' directory ... "
mkdir -p $bin 2> $err || err
cp -R ../src/${package_name}/bin/* $bin 2> $err || err
echo "OK"

echo -n "Building '${doc}' directory ... "
mkdir -p $doc 2> $err || err
cp -R ../src/${package_name}/doc/* $doc 2> $err || err
echo "OK"

echo -n "Building '${etc}' directory ... "
mkdir -p $etc 2> $err || err
cp ../src/${package_name}/etc/package_version $etc 2> $err || err
cp ../src/${package_name}/etc/warden-apache.conf $etc 2> $err || err
echo "OK"

echo -n "Building '${lib}' directory ... "
mkdir -p $lib 2> $err || err
cp -R ../src/${package_name}/lib/* $lib 2> $err || err
rm -rf ${lib}/*.t 2> $err || err
echo "OK"


# create tarball
echo -n "Creating $tar tarball ... "
tar czf $tar $package 2> $err || err
echo "OK"


#  create sign of tarball
echo -n "Creating $sig file ... "
sha1sum $tar > $sig 2> $err || err
echo "OK"


echo
echo "Building of $package package was SUCCESSFULL"

# cleanup section
rm -rf $package $err

exit 0
